@@ -1,4 +1,15 @@
 # (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 from collections import namedtuple
 import os
@@ -56,17 +67,19 @@ class Cacti(AgentCheck):
 
         # The rrdtool module is required for the check to work
         try:
-            import rrdtool
+            import rrdtool  # noqa
         except ImportError:
             raise Exception(
-                "Cannot import rrdtool module. This module is required for the cacti plugin to work correctly")
+                "Cannot import rrdtool module. This module is required for "
+                "the cacti plugin to work correctly")
 
         # Try importing MySQL
         try:
             import pymysql
         except ImportError:
             raise Exception(
-                "Cannot import PyMySQL module. This module is required for the cacti plugin to work correctly")
+                "Cannot import PyMySQL module. This module is required for "
+                "the cacti plugin to work correctly")
 
         connection = pymysql.connect(config.host, config.user, config.password, config.db)
 
