@@ -23,6 +23,12 @@ class Memory(checks.AgentCheck):
 
     def __init__(self, name, init_config, agent_config):
         super(Memory, self).__init__(name, init_config, agent_config)
+        process_fs_path_config = init_config.get('process_fs_path', None)
+        if process_fs_path_config:
+            psutil.PROCFS_PATH = process_fs_path_config
+            self.log.debug('The path of the process filesystem set to %s', process_fs_path_config)
+        else:
+            self.log.debug('The process_fs_path not set. Use default path: /proc')
 
     def check(self, instance):
         """Capture memory stats
