@@ -1,4 +1,15 @@
 # (C) Copyright 2015,2016 Hewlett Packard Enterprise Development LP
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 import logging
 import os
@@ -38,15 +49,18 @@ class Ntp(monasca_setup.detection.Plugin):
         else:
             ntp_server = 'pool.ntp.org'
         if re.match('^127', ntp_server):
-            log.warn("NTP Server points to localhost no value in collecting NTP metrics. Skipping configuration.")
+            log.warn(
+                "NTP Server points to localhost no value in collecting NTP metrics."
+                "Skipping configuration.")
             return None
-        config['ntp'] = {'init_config': None, 'instances': [{'name': ntp_server, 'host': ntp_server}]}
+        config['ntp'] = {'init_config': None, 'instances': [
+            {'name': ntp_server, 'host': ntp_server}]}
 
         return config
 
     def dependencies_installed(self):
         try:
-            import ntplib
+            import ntplib  # noqa
         except ImportError:
             return False
         else:
